@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# coding: utf-8
 from django.db import models
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy
@@ -25,9 +25,17 @@ class Person(models.Model):
     safe = models.CharField(
             max_length=200, blank=True, verbose_name=mark_safe("<b>Safe</b>"))
 
+    class Meta:
+        verbose_name = "person"
+        verbose_name_plural = "people"
+
     def __unicode__(self):
         return self.first_name
 
+    @property
+    def name(self):
+        return u"%s %s" % (self.first_name, self.last_name)
+
 
 class Occupation(models.Model):
     name = models.CharField(max_length=200)
@@ -39,6 +47,7 @@ class Occupation(models.Model):
 
 class Region(models.Model):
     name = models.CharField(max_length=200)
+    mayor = models.OneToOneField(Person, null=True)
 
     def __unicode__(self):
         return self.name
